# Driving an 8 Neopixel ring (0 to 7) with Circuitpython on Pico:ed V2
# Tony Goodhew 29th September 2022 
import board
import random
import neopixel_write
import digitalio
import time
from picoed import * # Includes music to play the notes
music.play("c2:1")   # Beep
display.scroll("Neopixels")
pin = digitalio.DigitalInOut(board.P0_A0) # Data to Neopixels
pin.direction = digitalio.Direction.OUTPUT
# Create buffer for 8 neopixels in a ring (3 * 8 elements)
buffer =[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0] # 24 zeros

def neo_clear(): # Clear all pixels to OFF - black
    for i in range(24):
        buffer[i] = 0
        pixel_off = bytearray(buffer)
        neopixel_write.neopixel_write(pin, pixel_off)
        
def neo_set(p,r,g,b): # Sets pixel p to rgb colour
    pos = p * 3
    buffer[pos] = g
    buffer[pos+1] = r
    buffer[pos+2] = b

def neo_update(): # Show the current pixel settings
    pixel_off = bytearray(buffer)
    neopixel_write.neopixel_write(pin, pixel_off)

# Single, stationary colours
neo_set(0,100,0,0)     # red
neo_set(1,100,100,0)   # yellow
neo_set(2,0,100,0)     # green
neo_set(3,0,100,100)   # cyan
neo_set(4,0,0,100)     # blue
neo_set(5,100,0,100)   # magenta
neo_set(6,100,100,100) # white
neo_set(7,60,25,10)    # orange

neo_update()          # Beeps by 2 methods: play/pitch
time.sleep(3)
neo_clear()
music.play("c2:1")
time.sleep(0.3)
music.pitch(440)
time.sleep(0.2)
music.pitch(0)
music.play("c2:1")

# Spinning Neopixels Red CW and Green CCW
# Beep when they bump
p = 0
p2 = 0
delay = 0.2
for i in range(50):
    p = (p+1) % 8       # red position
    neo_set(p,100,0,0)  # set red pixel
    p2 = (p2 -1) %8     # green position
    neo_set(p2,0,100,0) # set green position
    if p == p2:         # Check for overlap
        neo_set(p2,100,100,0) # Set joint position to yellow        
    neo_update()        # Display the changes
    if p == p2:         # Check for overlap
        music.play("c4:1") # Higher Beep
    time.sleep(delay)   # Wait
    neo_set(p,0,0,0)    # red OFF
    neo_set(p2,0,0,0)   # green OFF
    delay = delay - 0.003 # reduce delay

neo_clear() # All OFF
    
    